==> squid-3.1.0.2.tar.bz2: squid-3.1.0.2/src/ACLMaxUserIP.h <==
/*
 * $Id: ACLMaxUserIP.h,v 1.11 2008/02/26 21:49:34 amosjeffries Exp $
 *
 *
 * SQUID Web Proxy Cache          http://www.squid-cache.org/
 * ----------------------------------------------------------
 *
 *  Squid is the result of efforts by numerous individuals from
 *  the Internet community; see the CONTRIBUTORS file for full
 *  details.   Many organizations have provided support for Squid's
 *  development; see the SPONSORS file for full details.  Squid is
 *  Copyrighted (C) 2001 by the Regents of the University of
 *  California; see the COPYRIGHT file for full details.  Squid
 *  incorporates software developed and/or copyrighted by other
 *  sources; see the CREDITS file for full details.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 *
 * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
 */

#ifndef SQUID_ACLMAXUSERIP_H
#define SQUID_ACLMAXUSERIP_H

#include "ACL.h"
#include "ACLChecklist.h"

/// \ingroup ACLAPI
class ACLMaxUserIP : public ACL
{

public:
    MEMPROXY_CLASS(ACLMaxUserIP);

    ACLMaxUserIP(char const *);
    ACLMaxUserIP(ACLMaxUserIP const &);
    ~ACLMaxUserIP();
    ACLMaxUserIP&operator=(ACLMaxUserIP const &);

    virtual ACL *clone()const;
    virtual char const *typeString() const;
    virtual void parse();
    virtual int match(ACLChecklist *checklist);
    virtual wordlist *dump() const;
    virtual bool empty () const;
    virtual bool valid () const;
    virtual bool requiresRequest() const {return true;}

    int getMaximum() const {return maximum;}

    int getStrict() const {return flags.strict;}

private:
    static Prototype RegistryProtoype;
    static ACLMaxUserIP RegistryEntry_;

    int match(AuthUserRequest *, IPAddress const &);
    char const *class_;
    int maximum;

    struct Flags {
        Flags() : strict(0) {}

        unsigned int strict:1;
    } flags;
};

MEMPROXY_CLASS_INLINE(ACLMaxUserIP)          /**DOCS_NOSEMI*/

#endif /* SQUID_ACLMAXUSERIP_H */

==> squid-3.1.0.4.tar.bz2: squid-3.1.0.4/src/ACLMaxUserIP.h <==
/*
 * $Id: ACLMaxUserIP.h,v 1.11 2008/02/26 21:49:34 amosjeffries Exp $
 *
 *
 * SQUID Web Proxy Cache          http://www.squid-cache.org/
 * ----------------------------------------------------------
 *
 *  Squid is the result of efforts by numerous individuals from
 *  the Internet community; see the CONTRIBUTORS file for full
 *  details.   Many organizations have provided support for Squid's
 *  development; see the SPONSORS file for full details.  Squid is
 *  Copyrighted (C) 2001 by the Regents of the University of
 *  California; see the COPYRIGHT file for full details.  Squid
 *  incorporates software developed and/or copyrighted by other
 *  sources; see the CREDITS file for full details.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 *
 * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
 */

#ifndef SQUID_ACLMAXUSERIP_H
#define SQUID_ACLMAXUSERIP_H

#include "ACL.h"
#include "ACLChecklist.h"

/// \ingroup ACLAPI
class ACLMaxUserIP : public ACL
{

public:
    MEMPROXY_CLASS(ACLMaxUserIP);

    ACLMaxUserIP(char const *);
    ACLMaxUserIP(ACLMaxUserIP const &);
    ~ACLMaxUserIP();
    ACLMaxUserIP&operator=(ACLMaxUserIP const &);

    virtual ACL *clone()const;
    virtual char const *typeString() const;
    virtual void parse();
    virtual int match(ACLChecklist *checklist);
    virtual wordlist *dump() const;
    virtual bool empty () const;
    virtual bool valid () const;
    virtual bool requiresRequest() const {return true;}

    int getMaximum() const {return maximum;}

    int getStrict() const {return flags.strict;}

private:
    static Prototype RegistryProtoype;
    static ACLMaxUserIP RegistryEntry_;

    int match(AuthUserRequest *, IpAddress const &);
    char const *class_;
    int maximum;

    struct Flags {
        Flags() : strict(0) {}

        unsigned int strict:1;
    } flags;
};

MEMPROXY_CLASS_INLINE(ACLMaxUserIP)          /**DOCS_NOSEMI*/

#endif /* SQUID_ACLMAXUSERIP_H */
